@@ -89,8 +89,8 @@ def test_e2e_example(e2e_fixture: End2EndFixture) -> None:
 
                     result += ''.join(output)
 
-                    if code != 0:
-                        print(''.join(output))
+                if code != 0:
+                    print(''.join(output))
 
             assert code == 0
             assert 'ERROR' not in result
@@ -112,6 +112,22 @@ def test_e2e_example(e2e_fixture: End2EndFixture) -> None:
             assert 'sending "client_server" from CLIENT' in result
             assert "received from CLIENT" in result
             assert "AtomicCustomVariable.foobar='foobar'" in result
+
+            # check debugging and that task index -> step expression is correct
+            assert 'executing task 1 of 2: unknown' in result
+            assert (
+                'executing task 2 of 2: Then get request with name "get-dog-facts" from endpoint '
+                '"/api/v1/resources/dogs?number={{ AtomicRandomInteger.dog_facts_count }}'
+            ) in result
+
+            assert 'executing task 1 of 3: unknown' in result
+            assert 'executing task 2 of 3: Then get request with name "get-cat-facts" from endpoint "/facts?limit={{ AtomicRandomInteger.cat_facts_count }}"' in result
+            assert 'executing task 3 of 3: And send message "{\'client\': \'server\'}"' in result
+
+            assert 'executing task 1 of 4: unknown' in result
+            assert 'executing task 2 of 4: Then get request with name "1-get-book" from endpoint "/books/{{ AtomicCsvRow.books.book }}.json | content_type=json"' in result
+            assert 'executing task 3 of 4: Then get request with name "2-get-author" from endpoint "{{ author_endpoint }}.json | content_type=json"' in result
+            assert 'executing task 4 of 4: Then log message "AtomicCustomVariable.foobar=\'{{ steps.custom.AtomicCustomVariable.foobar }}\'"' in result
     except:
         if result is not None:
             print(result)
